Module error

Module error 

Error module.

Enums

ArrayError
Possible errors when working with the large array type
AttestationReportError
Errors which may be encountered when handling attestation reports
CertError
Errors which may be encountered through misuse of the User API.
FirmwareError
There are a number of error conditions that can occur between this layer all the way down to the SEV platform. Most of these cases have been enumerated; however, there is a possibility that some error conditions are not encapsulated here.
GCTXError
Errors which may be encountered when building custom guest context.
HashstickError
Errors which may be encountered when handling Version Loaded Endorsement Keys (VLEK) Hashsticks.
IdBlockError
Errors when calculating the ID BLOCK
MeasurementError
Errors which may be encountered when calculating the guest measurement.
OVMFError
Errors which may be encountered when handling OVMF data
SevError
Error conditions returned by the SEV platform or by layers above it (i.e., the Linux kernel).
SevHashError
Errors which may be encountered when building SEV hashes.
UserApiError
Wrapper Error for Firmware or User API Errors
VmmError
An error representingthe upper 32 bits of a SW_EXITINFO2 field set by the VMM.