pub enum HashstickError {
InvalidLength,
EmptyHashstickBuffer,
InvalidReservedField,
UnknownError,
}Expand description
Errors which may be encountered when handling Version Loaded Endorsement Keys (VLEK) Hashsticks.
Variants
InvalidLength
Hashstick length does not match what was specified in the buffer.
EmptyHashstickBuffer
No hashstick was provided
InvalidReservedField
Invalid reserved field in the hashstick.
UnknownError
Unknown Error.