VmmError

Enum VmmError 

pub enum VmmError {
    InvalidCertificatePageLength = 1,
    RateLimitRetryRequest = 2,
    Unknown = 3,
}
An error representingthe upper 32 bits of a SW_EXITINFO2 field set by the VMM.

Variants



InvalidCertificatePageLength = 1

If there are not enough guest pages to hold the certificate table and certificate data, the hypervisor will return the required number of pages needed to hold the certificate table and certificate data in the RBX register and set the SW_EXITINFO2 field to 0x0000000100000000.



RateLimitRetryRequest = 2

It is not expected that a guest would issue many Guest Request NAE events. However, access to the SNP firmware is a sequential and synchronous operation. To avoid the possibility of a guest creating a denial-of-service attack against the SNP firmware, it is recommended that some form of rate limiting be implemented should it be detected that a high number of Guest Request NAE events are being issued. To allow for this, the hypervisor may set the SW_EXITINFO2 field to 0x0000000200000000, which will inform the guest to retry the request.



Unknown = 3

Nothing more implemented yet.