Error module.
Enums
- Array
Error - Possible errors when working with the large array type
- Attestation
Report Error - Errors which may be encountered when handling attestation reports
- Cert
Error - Errors which may be encountered through misuse of the User API.
- Firmware
Error - There are a number of error conditions that can occur between this layer all the way down to the SEV platform. Most of these cases have been enumerated; however, there is a possibility that some error conditions are not encapsulated here.
- GCTX
Error - Errors which may be encountered when building custom guest context.
- Hashstick
Error - Errors which may be encountered when handling Version Loaded Endorsement Keys (VLEK) Hashsticks.
- IdBlock
Error - Errors when calculating the ID BLOCK
- Measurement
Error - Errors which may be encountered when calculating the guest measurement.
- OVMF
Error - Errors which may be encountered when handling OVMF data
- SevError
- Error conditions returned by the SEV platform or by layers above it (i.e., the Linux kernel).
- SevHash
Error - Errors which may be encountered when building SEV hashes.
- User
ApiError - Wrapper Error for Firmware or User API Errors
- VmmError
- An error representingthe upper 32 bits of a SW_EXITINFO2 field set by the VMM.